@@ -6,11 +6,15 @@ class Point:
     latitude: float
     longitude: float
 
+    def to_mongodb(self):
+        # Mainly used for testing
+        return {"type": "Point", "coordinates": [self.longitude, self.latitude]}
+
 
 @dataclass
 class PhoneNumber:
-    country_code: int
-    national_number: int
+    country_code: str
+    national_number: str
     international_format: str = field(init=False)
 
     def __post_init__(self):
