@@ -18,6 +18,8 @@ class BusinessException(Exception):
         _extra_info = kwargs.get("extra_info", {})
         if isinstance(_extra_info, dict) and _extra_info:
             self.extra_info = _extra_info
+        else:
+             self.extra_info = {}
 
     def serialize(self) -> Dict[str, Any]:
         """Serializes into a dictionary the exception, useful for JSON responses"""
