@@ -13,8 +13,16 @@ except ImportError:
     warn("phonenumbers is not found and it's used for some classes inside this file")
 
 
-from marshmallow import EXCLUDE, Schema, ValidationError, fields, validate, validates
-from pronto_commons.entities import PhoneNumber
+from marshmallow import (
+    EXCLUDE,
+    Schema,
+    ValidationError,
+    fields,
+    validate,
+    validates,
+    post_load,
+)
+from pronto_commons.entities import PhoneNumber, Point
 from pronto_commons.images import convert_base64_to_image, return_extension_from_base64
 from pronto_commons.utils import FileBytesExtension
 
@@ -71,11 +79,16 @@ class Base64ImageField(fields.Field):
             and the second the extension
         """
         try:
-            profile_picture_extension = return_extension_from_base64(value)
+            profile_picture_extension = return_extension_from_base64(
+                base64_string=value
+            )
             if not profile_picture_extension:
                 raise ValidationError("No extension found on image")
             return FileBytesExtension(
-                (convert_base64_to_image(value), profile_picture_extension)
+                (
+                    convert_base64_to_image(base64_string=value),
+                    profile_picture_extension,
+                )
             )
         except Exception as e:
             raise ValidationError(
@@ -114,3 +127,19 @@ class ObjectIdField(fields.Field):
             return ObjectId(value)
         except Exception as e:
             raise ValidationError("The field must be a valid ObjectId") from e
+
+
+class PointValidation(Schema):
+    """
+    Schema to validate a request of latitude and longitude and return a Point
+    """
+
+    latitude = fields.Float(required=True)
+    longitude = fields.Float(required=True)
+
+    @post_load
+    def convert_to_point(self, in_data, **kwargs) -> Point:
+        return Point(latitude=in_data["latitude"], longitude=in_data["longitude"])
+
+    class Meta:
+        unknown = EXCLUDE
\ No newline at end of file
