@@ -1,5 +1,7 @@
-from typing import Dict
+from contextlib import ContextDecorator
+from typing import Any, Dict, Generic, Optional, Type, TypeVar
 
+import mongoengine
 from bson import ObjectId
 
 from pronto_commons.utils import get_jwt_token
@@ -29,3 +31,26 @@ def transform_location_to_geojson(*, latitude: float, longitude: float) -> Dict:
     :return: The GeoJSON point
     """
     return {"coordinates": [float(longitude), float(latitude)], "type": "Point"}
+
+
+T = TypeVar("T")
+
+
+class MongoContext(Generic[T], ContextDecorator):
+    t: mongoengine.Document
+
+    def __init__(self, t: Type[T], kwargs: Optional[Dict[str, Any]] = None) -> None:
+        if kwargs is None:
+            kwargs = {}
+        self.kwargs = kwargs
+        self.t = t
+
+    def __enter__(self) -> T:
+        save_before_deleting = self.kwargs.pop("save_before_deleting", False)
+        self.obj = self.t(**self.kwargs)
+        if save_before_deleting:
+            self.obj.save()
+        return self.obj
+
+    def __exit__(self, *exc: Any) -> None:
+        self.obj.delete()
